package workspace

import (
	"cloud.o-forge.io/core/oc-lib/dbs/mongo"
	"cloud.o-forge.io/core/oc-lib/models/utils"
)

type WorkspaceMongoAccessor struct {
	utils.AbstractAccessor
}

func (wfa *WorkspaceMongoAccessor) DeleteOne(id string) (utils.DBObject, int, error) {
	return wfa.GenericDeleteOne(id, wfa)
}

func (wfa *WorkspaceMongoAccessor) UpdateOne(set utils.DBObject, id string) (utils.DBObject, int, error) {
	return wfa.GenericUpdateOne(set, id, wfa, &Workspace{})
}

func (wfa *WorkspaceMongoAccessor) StoreOne(data utils.DBObject) (utils.DBObject, int, error) {
	return wfa.GenericStoreOne(data, wfa)
}

func (wfa *WorkspaceMongoAccessor) CopyOne(data utils.DBObject) (utils.DBObject, int, error) {
	return wfa.GenericStoreOne(data, wfa)
}

func (wfa *WorkspaceMongoAccessor) LoadOne(id string) (utils.DBObject, int, error) {
	var workflow Workspace
	res_mongo, code, err := mongo.MONGOService.LoadOne(id, wfa.GetType())
	if err != nil {
		wfa.Logger.Error().Msg("Could not retrieve " + id + " from db. Error: " + err.Error())
		return nil, code, err
	}
	res_mongo.Decode(&workflow)
	obj := &Workspace{Active: false}
	mongo.MONGOService.UpdateMultiple(obj, map[string]interface{}{"active": true}, wfa.GetType())
	obj = &Workspace{Active: true}
	wfa.UpdateOne(obj, id)

	return &workflow, 200, nil
}

func (wfa WorkspaceMongoAccessor) LoadAll() ([]utils.ShallowDBObject, int, error) {
	objs := []utils.ShallowDBObject{}
	res_mongo, code, err := mongo.MONGOService.LoadAll(wfa.GetType())
	if err != nil {
		wfa.Logger.Error().Msg("Could not retrieve any from db. Error: " + err.Error())
		return nil, code, err
	}
	var results []Workspace
	if err = res_mongo.All(mongo.MngoCtx, &results); err != nil {
		return nil, 404, err
	}
	for _, r := range results {
		objs = append(objs, &r.AbstractObject)
	}
	return objs, 200, nil
}
